import React, { MouseEvent } from 'react';
export interface ListItemProps {
    avatar?: React.ReactNode;
    circularProgressBar?: React.ReactNode;
    classNames?: string[];
    primary: React.ReactNode;
    secondary?: React.ReactNode;
    to?: string;
    handleClick?: React.MouseEventHandler;
    icon?: React.ReactNode;
    primaryEnd?: React.ReactNode;
    secondaryEnd?: React.ReactNode;
    header?: boolean;
    routerLink?: any;
}
export interface ListProps {
    /**
     * CSS class name
     */
    className?: string;
    /**
     * Whether a divider is shown between two item lists
     */
    divider?: boolean;
    /**
     * If true, the left and right padding for the item content is removed.
     */
    disableGutters?: boolean;
    /**
     * An array of params that will be passed to the `handleClick` method of each menu item.
     */
    handleClickParams?: (string | number)[];
    /**
     * An array of objects with the following properties:
     *
     * Name | Type | Description | Default
     * --- | --- | --- | ---
     * avatar | React.ReactElement | An `Avatar` component. If both avatar and icon are set, only avatar will be shown. | -
     * circularProgressBar | React.ReactElement | A 'CircularProgressBar` component. If both progress bar and avatar are set, only avatar will be shown. | -
     * classNames | string[] | An array of classnames to be passed to ListItem. | -
     * primary | string | Item's primary text. | -
     * secondary | string | Item's secondary text. | -
     * to | string | The URL to follow when the list item is clicked. | -
     * icon | React.ReactElement | If set, an icon is showed before text. If both `avatar` and `icon` are set only `avatar` will be shown. | -
     * primaryEnd | string | Primary text to show at the right side of the item. | -
     * secondaryEnd | string | Secondary text to show at the right side of the item. | -
     * handleClick | function | A function that will be executed on item's `onClick` method, e.g. `(e) => console.log(e)`. By default, `e`, the React's synthetic event, is passed to that function. When additional parameters are passed by another API implementation, e.g. `Table`, it is explicitly documented. | -
     * header | boolean | When true the list item becomes a header | false
     * routerLink | any | The Link component of your router library of choice | -
     */
    items: ListItemProps[];
}
export declare type ListItemBaseProps = ListItemProps & {
    component?: any;
    /**
     * A function that will be executed on item's `onClick` method,
     * e.g. `(e) => console.log(e)`. By default, `e`, the React's synthetic event, is passed to that
     * function. When additional parameters are passed by another API implementation, e.g. `Table`,
     * it is explicitly documented.
     */
    handleClick?: (event: MouseEvent<HTMLButtonElement | HTMLAnchorElement>, x?: string) => void;
    /**
     * Classname to be passed to ListItem. It is used internally to pass active class and other classes passed by the user
     */
    className?: string;
    /**
     * If true, the left and right padding for the item content is removed.
     */
    disableGutters?: boolean;
};
/**
 * Lists are a continuous group of text or images. They are composed of items
 * containing primary and supplemental actions, which are represented by icons
 * and text.
 */
export declare const List: React.FC<ListProps>;
