import React, { FC } from 'react';
export interface Items {
    value: string | number;
    text: string;
}
export interface SelectProps {
    /**
     * CSS class name
     */
    className?: string;
    /**
     * Whether the `input` element is disabled.
     */
    disabled?: boolean;
    /**
     * Whether error state is true.
     */
    error?: boolean;
    /**
     * Helper text that appears below the input, useful for showing hints.
     */
    helperText?: React.ReactNode;
    /**
     * The id of the `input` element.
     */
    id: string;
    /**
     * Any array of items that become select's `option` elements.
     */
    items?: Items[];
    /**
     * The content of the label, if empty no label will be shown.
     */
    label?: React.ReactNode;
    /**
     * Text for the placeholder.
     */
    placeholder?: string;
    /**
     * Whether this input is required, will append an asterisk if a label is used.
     */
    required?: boolean;
    /**
     * The value for the `input` element. Setting to an empty string '' selects
     * no option. Usually is controlled by the application state.
     */
    value?: any;
    /**
     * The function to be executed when an option is selected
     */
    onChange?: any;
    renderValue?: any;
    /**
     * Whether multiple elements can be selected.
     */
    multiple?: boolean;
    /**
     * Pass a ref to the input element.
     */
    inputRef?: React.Ref<any>;
    /**
     * When set to true, label is shown on the left.
     */
    labelLeft?: boolean;
}
export declare const Select: FC<SelectProps>;
