import React, { FC } from 'react';
export declare type TabsVariant = 'fullWidth' | 'standard';
export interface TabProps {
    content: React.ReactNode;
    icon?: React.ReactElement;
    index: number;
    title: string;
}
export interface TabsProps {
    /**
     * CSS class name
     */
    className?: string;
    /**
     * An array of objects with the following properties:
     *
     * Name | Type | Description | Default
     * --- | --- | --- | ---
     * content | React.ReactNode | The content of the tab. It must be a React component. | -
     * icon | React.ReactElement | If set, an icon is showed before text. If both `avatar` and `icon` are set only `avatar` will be shown. | -
     * index | number | The index of the tab (starting from 0) | -
     * title | string | The title of the tab | -
     */
    tabs: TabProps[];
    /**
     * The variant of the `Tabs` component.
     * In `fullWidth` mode the tabs will take up all the available space.
     */
    variant?: TabsVariant;
}
/**
 * Tabs organize and allow navigation between groups of content that are related and at
 * the same level of hierarchy.
 */
export declare const Tabs: FC<TabsProps>;
