import React, { FC } from 'react';
export interface CardProps {
    /**
     * An 'Avatar' component. If set, the card header is shown with `title` and `subtitle`.
     */
    avatar?: React.ReactNode;
    /**
     * The `CardBody` and `CardActions` components.
     */
    children?: React.ReactNode;
    /**
     * If true, the left and right padding for the card content is removed.
     */
    disableGutters?: boolean;
    /**
     * If set, the card acts as button that follows this URL.
     */
    href?: string;
    /**
     * The 'src' attribute for the image to be displayed above content area.
     */
    image?: string;
    /**
     * Text for card's subtitle.
     */
    subtitle?: string;
    /**
     * Text for card's title.
     */
    title?: string;
}
/**
 * Actions area for card
 * @param children The contents of the component
 */
export declare const CardActions: FC;
/**
 * Main body of the card
 * @param children The contents of the component
 * @param className The CSS class to pass to component
 */
export declare const CardBody: FC<{
    className?: string;
}>;
/**
 * Cards are surfaces that display content and actions on a single topic. They should be easy to scan for relevant and
 * actionable information. Elements, like text and images, should be placed on them in a way that clearly indicates
 * hierarchy.
 *
 * A `Card` may contain two optional components:
 *
 * - A `CardBody` component which contains wrapped content
 * - A `CardActions` component with elements for action, like buttons or icons
 */
export declare const Card: FC<CardProps>;
