import React, { FC } from 'react';
export interface DialogProps {
    /**
     * The content of the dialog
     */
    children: React.ReactNode;
    /**
     * Whether dialog should be open
     */
    open: boolean;
    /**
     * Dialog's title
     */
    title?: string;
    /**
     * Function that toggles dialog visibility
     */
    toggleDialog(event: React.MouseEvent<HTMLButtonElement>): void;
    /**
     * If `true`, hitting escape will not fire the `onClose` callback.
     * @default false
     */
    disableEscapeKeyDown?: boolean;
    /**
     * If true, the dialog stretches to maxWidth.
     */
    fullWidth?: boolean;
    /**
     * Determine the max-width of the dialog. The dialog width grows with the size of the screen. Set to false to disable maxWidth.
     */
    maxWidth?: 'xs' | 'sm' | 'md' | 'lg' | 'xl' | false;
}
/**
 * Actions area for dialog, usually buttons
 * @param children The contents of the component
 */
export declare const DialogActions: FC;
/**
 * Main body of the dialog
 * @param children The contents of the component
 */
export declare const DialogBody: FC;
export declare const Dialog: FC<DialogProps>;
